/******************************************************************************/
/* Copyright (C) SEIKO EPSON CORPORATION 2010. All rights reserved.           */
/******************************************************************************/
/*                                                                            */
/* PLQStatusApiDef.h                                                          */
/*                                                                            */
/* Definition of the constants and also data type.                            */
/*                                                                            */
/* Modification history                                                       */
/* -------------------------------------------------------------------------- */
/* 2010-05-14   New                                                           */
/*                                                                            */
/******************************************************************************/

#if !defined(_PLQSTATUSAPIDEF_H)
#define _PLQSTATUSAPIDEF_H


#if defined(WIN32)

typedef LONG            EPBS_INT32;
typedef BYTE            EPBS_UINT8;
typedef DWORD           EPBS_UINT32;
typedef LPBYTE          EPBS_PUINT8;
typedef LPCSTR          EPBS_PCCHAR;
typedef LPDWORD         EPBS_PUINT32;
typedef LPINT           EPBS_PINT32;
typedef CHAR            EPBS_CHAR;
typedef LPSTR           EPBS_PCHAR;
typedef LPVOID          EPBS_PVOID;
typedef LPWORD          EPBS_PUINT16;
typedef WORD            EPBS_UINT16;
typedef BOOL            EPBS_BOOL;
typedef RECT            EPBS_RECT;
typedef LPHANDLE        EPBS_PHANDLE;
typedef HWND            EPBS_HWND;

#elif defined(__GNUC__)

typedef int32_t         EPBS_INT32;
typedef uint8_t         EPBS_UINT8;
typedef uint32_t        EPBS_UINT32;
typedef EPBS_UINT8*     EPBS_PUINT8;
typedef const char*     EPBS_PCCHAR;
typedef EPBS_UINT32*    EPBS_PUINT32;
typedef int32_t*        EPBS_PINT32;
typedef char            EPBS_CHAR;
typedef EPBS_CHAR*      EPBS_PCHAR;
typedef void*           EPBS_PVOID;
typedef uint16_t        EPBS_UINT16;
typedef EPBS_UINT16*    EPBS_PUINT16;
typedef EPBS_INT32      EPBS_BOOL;
typedef void**          EPBS_PHANDLE;
typedef void*           EPBS_HWND;
typedef struct {
    EPBS_INT32 left;
    EPBS_INT32 top;
    EPBS_INT32 right;
    EPBS_INT32 bottom;
} EPBS_RECT;

#endif


/******************************************************************************/
/******************************************************************************/
/* ERROR CODE                                                                 */
/******************************************************************************/
/******************************************************************************/
#define     SUCCESS                     0           /* Success                                  */

#define     ERR_UNKNOWN                 -9999       /* Unknown Error                            */

#define     ERR_TYPE                    -10         /* nType error                              */
#define     ERR_OPENED                  -20         /* Already opened                           */
#define     ERR_NO_PRINTER              -30         /* There is not printer driver              */
#define     ERR_NO_MEMORY               -50         /* No memory                                */
#define     ERR_HANDLE                  -60         /* Invalid handle                           */
#define     ERR_TIMEOUT                 -70         /* Time out                                 */
#define     ERR_ACCESS                  -80         /* cannot read/write                        */
#define     ERR_PARAM                   -90         /* param error                              */
#define     ERR_NOT_SUPPORT             -100        /* not support                              */
#define     ERR_OFFLINE                 -110        /* now offline                              */
#define     ERR_WITHOUT_CB              -130        /* without callback function                */
#define     ERR_BUFFER_OVER_FLOW        -140        /* Read buffer over flow                    */
#define     ERR_ENABLE                  -160        /* BiOpenMonPrinter() is already called     */
#define     ERR_DISK_FULL               -170        /* Capacity of a disk is insufficient       */
#define     ERR_NO_IMAGE                -180        /* No image data                            */
#define     ERR_ENTRY_OVER              -190        /* Registration number-of-cases over        */
#define     ERR_CROPAREAID              -200        /* No specific CropAreaID                   */
#define     ERR_EXIST                   -210        /* Already the same thing                   */
#define     ERR_NOT_FOUND               -220        /* Not found                                */
#define     ERR_IMAGE_FILEOPEN          -230        /* Open failure                             */
#define     ERR_IMAGE_UNKNOWNFORMAT     -240        /* Unknown format                           */
#define     ERR_IMAGE_FAILED            -250        /* Image creation failure                   */
#define     ERR_WORKAREA_NO_MEMORY      -260        /* No memory for WORKAREA                   */
#define     ERR_WORKAREA_UNKNOWNFORMAT  -270        /* Image creation failure because of format injustice */
#define     ERR_WORKAREA_FAILED         -280        /* WORKAREA creation failure                */
#define     ERR_IMAGE_FILEREAD          -290        /* Image file read error                    */
#define     ERR_PAPERINSERT_TIMEOUT     -300        /* Image paper insert error of timeout      */
#define     ERR_EXEC_FUNCTION           -310        /* Other API is running                     */
#define     ERR_RESET                   -400        /* Now printer is resetting                 */
#define     ERR_ABORT                   -430        /* Because BiSCNMICRCancelFunction was called, processing was stopped */
#define     ERR_MICR                    -440        /* Error occurred during MICR processing    */
#define     ERR_SCAN                    -450        /* Error occurred during the image scan     */
#define     ERR_LINE_OVERFLOW           -460        /* A line overflow has occurred during transaction printing */
#define     ERR_NOT_EXEC                -470        /* Processing is not executed               */
#define     ERR_PAPER_PILED             -1010       /* Paper pilling error                      */
#define     ERR_PAPER_JAM               -1020       /* Paper jam has occurred                   */
#define     ERR_COVER_OPEN              -1030       /* Cover open error                         */
#define     ERR_MICR_NODATA             -1040       /* MICR data is not existing                */
#define     ERR_MICR_BADDATA            -1050       /* MICR data is not able to recognize       */
#define     ERR_MICR_NOISE              -1070       /* Noise error has occurred during MICR reading */
#define     ERR_SCN_COMPRESS            -1080       /* Scan image data compressing error        */
#define     ERR_PAPER_EXIST             -1090       /* Because there is a paper on the path, API can not be execute */
#define     ERR_PAPER_INSERT            -1100       /* Paper insertion error                    */
#define     ERR_BARCODE_NODATA          -1130       /* Barcode data is not existing             */
#define     ERR_UNLOCKED                -1140       /* Port Unlocked                            */
#define     ERR_NET_CONNECTED           -1150       /* Network connection fails                 */
#define     ERR_MSRW_NODATA             -1160       /* MSR data is not existing                 */
#define     ERR_IMAGE_FILEREMOVE        -1170       /* Remove failure                           */
#define     ERR_MSRW_WRITE              -1180       /* MSW data is not written                  */

/******************************************************************************/
/******************************************************************************/
/* ASB Bit                                                                    */
/******************************************************************************/
/******************************************************************************/
#define     ASB_NO_RESPONSE                             0x00000001  /* No response              */
#define     ASB_OFF_LINE                                0x00000008  /* Off-line                 */
#define     ASB_COVER_OPEN                              0x00000020  /* Cover is open            */
#define     ASB_WAIT_PEPRT_EJECT                        0x00000100  /* Waiting for slip remove  */
#define     ASB_MECHANICAL_ERR                          0x00000400  /* Mechanical error         */
#define     ASB_UNRECOVER_ERR                           0x00002000  /* Unrecoverable error      */
#define     ASB_PAPER_INTERMEDIATE                      0x00010000  /* Not paper in Paper intermediate sensor */
#define     ASB_MAIN_NEAR_FULL                          0x00020000  /* Main Pocket not Near Full */
#define     ASB_EJECT_SENSOR_NO_PAPER                   0x00040000  /* Eject sensor no paper    */
#define     ASB_SUB_NEAR_FULL                           0x00080000  /* Sub Pocket not Near Full */
#define     ASB_SLIP_PAPER_SIZE                         0x00200000  /* Not paper in Slip Paper size sensor */
#define     ASB_ASF_PAPER                               0x00400000  /* No paper                 */
#define     ASB_STAMP_EXIST                             0x02000000  /* Stamp not Exist          */
#define     ASB_WAIT_INSERT                             0x20000000  /* Wait insert              */
#define     ASB_FRANKING_SENSOR                         0x40000000  /* Not paper in Franking sensor */

#define     ESCMC_ASB_NO_RESPONSE                       0x00000001  /* No response              */
#define     ESCMC_ASB_OFFLINE                           0x00000002  /* Off-line                 */
#define     ESCMC_ASB_PAPER_FEED                        0x00000004  /* Paper is now feeding     */
#define     ESCMC_ASB_PAPER_SET                         0x00000008  /* Paper is now setting     */
#define     ESCMC_ASB_COVER_STATUS                      0x00000010  /* Cover state              */

#define     ESCMC_ASB_PAPER_JAM                         0x00000001  /* Paper jam has occurred   */
#define     ESCMC_ASB_NO_PAPER                          0x00000002  /* No paper                 */
#define     ESCMC_ASB_PAPER_FEED_ERROR                  0x00000004  /* Not feed                 */
#define     ESCMC_ASB_SKEW                              0x00000008  /* Skew error               */
#define     ESCMC_ASB_PAPER_EJECT                       0x00000010  /* Not eject the paper      */
#define     ESCMC_ASB_PAPER_EJECT_INCOMPLETE            0x00000020  /* Remove the paper does not end */
#define     ESCMC_ASB_RELEASE_LEVER                     0x00000040  /* Release lever error      */
#define     ESCMC_ASB_CHANGE_INCOMPLETE                 0x00000100  /* Change incomplete        */
#define     ESCMC_ASB_PAPER_REBUILDING                  0x00000200  /* Paper rebuilding error   */
#define     ESCMC_ASB_PAPER_WRONG_INSERT                0x00000400  /* Paper mis-insertion      */
#define     ESCMC_ASB_COVER_OPEN                        0x00000800  /* Cover is open            */
#define     ESCMC_ASB_PAPER_SIZE_DIFFERENCE             0x00001000  /* Paper size               */
#define     ESCMC_ASB_NO_RIBBON                         0x00002000  /* No ribbon                */
#define     ESCMC_ASB_INITIALIZE_SETTING                0x00004000  /* Not initialize           */
#define     ESCMC_ASB_RIBBON_JAM                        0x00010000  /* Ribbon jam has occurred  */
#define     ESCMC_ASB_PAPER_THICKNESS_LEVER_POSITION    0x00020000  /* Paper thickness lever position error */
#define     ESCMC_ASB_WAIT_TEAR_OFF_RECOVER             0x00040000  /* Tear off waitting        */
#define     ESCMC_ASB_PAPER_CUT_MISS                    0x00080000  /* Paper cut error          */
#define     ESCMC_ASB_PAPER_RECOGNITION                 0x00100000  /* Paper recognition error  */
#define     ESCMC_ASB_CUTTER_ERROR                      0x00200000  /* Cutter error             */
#define     ESCMC_ASB_CUTTER_JAM                        0x00400000  /* Cutter jam has occurred  */
#define     ESCMC_ASB_CUTTER_COVER_ERROR                0x01000000  /* Cutter cover is open     */

#define     ESCMC_ASB_FATAL_ERROR                       0x00000001  /* Fatal error              */

#define     ESCMC_ASB_HEAD_HOT_ERROR                    0x00000001  /* Head hot error           */



/******************************************************************************/
/******************************************************************************/
/* Function Parameter                                                         */
/******************************************************************************/
/******************************************************************************/
/*========================================================*/
/* BiOpenMonPrinter()                                     */
/*========================================================*/
/*------------------------------------*/
/* Open Type                          */
/*------------------------------------*/
#define     TYPE_PRINTER                    2           /* use printer driver name  */

/*========================================================*/
/* BiSetMultiStatusBackFunction()                         */
/*========================================================*/
/*------------------------------------*/
/* Status Type                        */
/*------------------------------------*/
#define     EPS_STATUS_INDEX_GENERAL                        1       /* General Status             */
#define     EPS_STATUS_INDEX_RETURNNABLE_ERROR              2       /* Returnnable error Status   */
#define     EPS_STATUS_INDEX_UNRETURNABLE_ERROR             3       /* Unreturnnable error Status */
#define     EPS_STATUS_INDEX_AUTO_CARRIAGE_RETURN_ERROR     4       /* Auto Return error Status   */

/*========================================================*/
/* BiSCNSetImageQuality()                                 */
/*========================================================*/
/*------------------------------------*/
/* Scale Option                       */
/*------------------------------------*/
#define     EPS_BI_SCN_1BIT                 1           /* Monochrome */
#define     EPS_BI_SCN_8BIT                 8           /* Gray scale */
#define     EPS_BI_SCN_24BIT                24          /* RGB 24bit  */
/*------------------------------------*/
/* Color Option                       */
/*------------------------------------*/
#define     EPS_BI_SCN_MONOCHROME           48          /* Monochrome */
#define     EPS_BI_SCN_COLOR                49          /* Color      */
/*------------------------------------*/
/* Extensive Option                   */
/*------------------------------------*/
#define     EPS_BI_SCN_MANUAL               49          /* Manual                                           */
#define     EPS_BI_SCN_SHARP                50          /* Sharpness                                        */
#define     EPS_BI_SCN_SHARP_CUSTOM         51          /* Custom sharpness                                 */
#define     EPS_BI_SCN_SHARP_CUSTOM2        52          /* Combination of sharpness and custom sharpness    */
#define     EPS_BI_SCN_SHARP_CUSTOM3        53          /* Sharpness(eliminate checkered patterns)          */

/*========================================================*/
/* BiSCNSetImageFormat()                                  */
/*========================================================*/
/*------------------------------------*/
/* Format Option                      */
/*------------------------------------*/
#define     EPS_BI_SCN_TIFF                 1           /* TIFF format(CCITT Group 4)   */
#define     EPS_BI_SCN_RASTER               2           /* Raster Image                 */
#define     EPS_BI_SCN_BITMAP               3           /* Bitmap                       */
#define     EPS_BI_SCN_TIFF256              4           /* TIFF format(Gray scale)      */
#define     EPS_BI_SCN_JPEGHIGH             5           /* Jpeg format(High compressed) */
#define     EPS_BI_SCN_JPEGNORMAL           6           /* Jpeg format(Normal)          */
#define     EPS_BI_SCN_JPEGLOW              7           /* Jpeg format(Low compressed)  */
#define     EPS_BI_SCN_JTIFF                8           /* TIFF format(Jpeg compressed) */

/*========================================================*/
/* BiSCNSelectScanFace()                                  */
/*========================================================*/
#define     MF_SCAN_FACE_FRONT              0
#define     MF_SCAN_FACE_BACK               1

/*========================================================*/
/* BiGetOcrABText()                                       */
/*========================================================*/
#define     OCR_SOURCE_TRANSACTION_NUMBER   0
#define     OCR_SOURCE_IMAGE_FILE           1

/*========================================================*/
/* BiSetPrintStation()                                    */
/*========================================================*/
/*------------------------------------*/
/* Printing Station                   */
/*------------------------------------*/
#define     MF_ST_E_ENDORSEMENT             0x0004                  /* Electric endorse printing             */
#define     MF_ST_E_ENDORSEMENT_BACK        MF_ST_E_ENDORSEMENT     /* Electric endorse printing(back side)  */
#define     MF_ST_E_ENDORSEMENT_FRONT       0x0008                  /* Electric endorse printing(front side) */
#define     MF_ST_REAL_ENDORSEMENT          0x0010                  /* Real endorse printing                 */

/*========================================================*/
/* BiBufferedPrint()                                      */
/*========================================================*/
#define     MF_PRT_BUFFERING                1
#define     MF_PRT_EXEC                     2
#define     MF_PRT_CLEAR                    3

/*========================================================*/
/* BiSCNSetBehaviorToScnResult()                          */
/*========================================================*/
/*------------------------------------*/
/* Next Check                         */
/*------------------------------------*/
#define     MF_PROCESS_CONTINUE_OVERLAP     1
#define     MF_PROCESS_CONTINUE_NOOVERLAP   2
#define     MF_PROCESS_CONTINUE_CANCEL      3

/*========================================================*/
/* BiGetVersion()                                         */
/*========================================================*/
/*------------------------------------*/
/* Driver Type                        */
/*------------------------------------*/
#define     DRIVER_TYPE_PLQ22               3
/*------------------------------------*/
/* Type                               */
/*------------------------------------*/
#define     VERSION_TYPE_DRIVER             0x00000001
#define     VERSION_TYPE_OCR                0x00000004
#define     VERSION_TYPE_IMAGE              0x00000005
#define     VERSION_TYPE_BARCODE            0x00000007
#define     VERSION_TYPE_PDF                0x00000008
#define     VERSION_TYPE_DDE1               0x00000009
#define     VERSION_TYPE_DDE2               0x00000010
#define     VERSION_TYPE_PH                 0x00000011

/*========================================================*/
/* BiMICRClearSpaces()                                    */
/*========================================================*/
#define     CLEAR_SPACE_DISABLE             0
#define     CLEAR_SPACE_ENABLE              1

/*========================================================*/
/* BiSetOcrABAreaOrigin()                                 */
/*========================================================*/
#define     OCR_ORIGIN_TOP_LEFT             0
#define     OCR_ORIGIN_BOTTOM_LEFT          1
#define     OCR_ORIGIN_TOP_RIGHT            2
#define     OCR_ORIGIN_BOTTOM_RIGHT         3

/*========================================================*/
/* BiSetEndorseDirection()                                */
/*========================================================*/
#define     EENDORSE_DIRECTION_LEFTRIGHT    1
#define     EENDORSE_DIRECTION_TOPBOTTOM    2
#define     EENDORSE_DIRECTION_RIGHTLEFT    3
#define     EENDORSE_DIRECTION_BOTTOMTOP    4

/*========================================================*/
/* BiSCNSetImageTypeOption()                              */
/*========================================================*/
#define     EPS_BI_SCN_OPTION_NONE                      0
#define     EPS_BI_SCN_OPTION_INFRARED                  1
#define     EPS_BI_SCN_OPTION_DROPOUT_RED               2
#define     EPS_BI_SCN_OPTION_DROPOUT_GREEN             3
#define     EPS_BI_SCN_OPTION_DROPOUT_BLUE              4
#define     EPS_BI_SCN_OPTION_COLOR_ENHANCEMENT_RED     5
#define     EPS_BI_SCN_OPTION_COLOR_ENHANCEMENT_GREEN   6
#define     EPS_BI_SCN_OPTION_COLOR_ENHANCEMENT_BLUE    7

/*========================================================*/
/* BiSCNSetTextEnhancement()                              */
/*========================================================*/
#define     EPS_BI_SCN_TEXT_ENHANCEMENT_OFF     0
#define     EPS_BI_SCN_TEXT_ENHANCEMENT_ON      1

/*========================================================*/
/* BiSCNSetImageAdjustment()                              */
/*========================================================*/
/*------------------------------------*/
/* Brightness                         */
/*------------------------------------*/
#define     EPS_BI_SCN_BRIGHTNESS_DEFAULT   0
#define     EPS_BI_SCN_BRIGHTNESS_NONE      EPS_BI_SCN_BRIGHTNESS_DEFAULT
/*------------------------------------*/
/* Contrast                           */
/*------------------------------------*/
#define     EPS_BI_SCN_CONTRAST_DEFAULT     0
#define     EPS_BI_SCN_CONTRAST_NONE        EPS_BI_SCN_CONTRAST_DEFAULT
/*------------------------------------*/
/* Gamma                              */
/*------------------------------------*/
#define     EPS_BI_SCN_GAMMA_NONE           0
#define     EPS_BI_SCN_GAMMA_DEFAULT        22
#define     EPS_BI_SCN_GAMMA_10             10
#define     EPS_BI_SCN_GAMMA_18             18
#define     EPS_BI_SCN_GAMMA_22             22

/*========================================================*/
/* BiSCNSetScanDirection()                                */
/*========================================================*/
#define     EPS_BI_SCN_DIRECTION_AUTO       0
#define     EPS_BI_SCN_DIRECTION_FORWARD    1
#define     EPS_BI_SCN_DIRECTION_BACKWARD   2

/*========================================================*/
/* BiSetInternationalCharSet()                            */
/*========================================================*/
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_USA                  1
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_FRANCE               2
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_GERMANY              3
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_UNITED_KINGDOM       4
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_DENMARK              5
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_SWEDEN               6
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_ITALY                7
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_SPAIN                8
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_NORWAY               9
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_DENMARK2             10
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_SPAIN2               11
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_LATIN_AMERICA        12
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_LEGAL                13
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_JAPAN                14
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_SIMPLIFIED_CHINESE   15
#define     MF_BI_PRINT_INTERNATIONAL_CHAR_KOREA                16

/*========================================================*/
/* BiSetEndorseOrigin()                                   */
/*========================================================*/
#define     ENDORSE_ORIGIN_BOTTOM_LEFT                          0
#define     ENDORSE_ORIGIN_TOP_LEFT                             1

/*========================================================*/
/* BiESCNEnable()                                         */
/*========================================================*/
/*------------------------------------*/
/* Saved Method                       */
/*------------------------------------*/
#define     CROP_STORE_MEMORY               0           /* Saved memory */
#define     CROP_STORE_FILE                 1           /* Saved file   */

/*========================================================*/
/* BiESCNSetAutoSize()                                    */
/*========================================================*/
/*------------------------------------*/
/* Enable/Disable Autosize            */
/*------------------------------------*/
#define     CROP_AUTOSIZE_DISABLE           0           /* Disabled auto size  */
#define     CROP_AUTOSIZE_ENABLE            1           /* Enabled auto size */

/*========================================================*/
/* BiESCNSetRotate()                                      */
/*========================================================*/
/*------------------------------------*/
/* Enable/Disable Rotate              */
/*------------------------------------*/
#define     CROP_ROTATE_DISABLE             0                            /* Enabled rotate */
#define     CROP_ROTATE_ENABLE              1                            /* Disabled rotate */
#define     CROP_ROTATE_NONE                CROP_ROTATE_DISABLE          /* rotate None */
#define     CROP_ROTATE_RIGHT               CROP_ROTATE_ENABLE           /* rotate Right */
#define     CROP_ROTATE_LEFT                2                            /* rotate Left */

/*========================================================*/
/* BiESCNGetDeSkew(), BiESCNSetDeSkew()                   */
/*========================================================*/
#define     DESKEW_ALL                      0
#define     DESKEW_DISABLE                  65535

/*========================================================*/
/* BiESCNDefineCropArea()                                 */
/*========================================================*/
/*------------------------------------*/
/* CropArea Setting                   */
/*------------------------------------*/
#define     CROP_AREA_RESET_ALL             0           /* Delete all crop area  */
#define     CROP_AREA_ENTIRE_IMAGE          1           /* CropArea entire image */
#define     CROP_AREA_RIGHT                 65535       /* End X Point           */
#define     CROP_AREA_BOTTOM                65535       /* End Y Point           */

/*========================================================*/
/* BiESCNClearImage()                                     */
/*========================================================*/
/*------------------------------------*/
/* Delete Method                      */
/*------------------------------------*/
#define     CROP_CLEAR_ALL_IMAGE            0           /* Delete all image   */
#define     CROP_CLEAR_BY_FILEINDEX         1           /* Clear by fileIndex */
#define     CROP_CLEAR_BY_FILEID            2           /* Clear by fileId    */
#define     CROP_CLEAR_BY_IMAGETAGDATA      4           /* by imageTagData    */

/*========================================================*/
/* BiSCNMICRSetStatusBackFunction                         */
/*========================================================*/
/*------------------------------------*/
/* wMainStatus                        */
/*------------------------------------*/
#define     MF_FUNCTION_START               200
#define     MF_CHECKPAPER_PROCESS_START     201
#define     MF_DATARECEIVE_START            202
#define     MF_DATARECEIVE_DONE             203
#define     MF_CHECKPAPER_PROCESS_DONE      204
#define     MF_FUNCTION_DONE                205
#define     MF_DATARECEIVE_MICR_DONE        206
#define     MF_ERROR_OCCURED                299

/*========================================================*/
/* BiSCNMICRFunction                                      */
/* BiSCNMICRFunctionContinuously                          */
/* BiSCNMICRFunctionPostPrint                             */
/*========================================================*/
/*------------------------------------*/
/* wFunction                          */
/*------------------------------------*/
#define     MF_EXEC                         0x0000
#define     MF_MICR_RETRANS                 0x0002

#define     MF_SET_BASE_PARAM               0x0010
#define     MF_SET_MICR_PARAM               0x0011
#define     MF_SET_SCAN_FRONT_PARAM         0x0012
#define     MF_SET_SCAN_PARAM               0x0012
#define     MF_SET_SCAN_BACK_PARAM          (MF_SET_SCAN_FRONT_PARAM + 1)
#define     MF_SET_PRINT_PARAM              0x0014
#define     MF_SET_PROCESS_PARAM            0x0015
#define     MF_SET_BARCODE_FRONT_PARAM      0x0017
#define     MF_SET_BARCODE_PARAM            0x0017
#define     MF_SET_BARCODE_BACK_PARAM       (MF_SET_BARCODE_FRONT_PARAM + 1)

#define     MF_CLEAR_BASE_PARAM             0x0020
#define     MF_CLEAR_MICR_PARAM             0x0021
#define     MF_CLEAR_SCAN_FRONT_PARAM       0x0022
#define     MF_CLEAR_SCAN_PARAM             0x0022
#define     MF_CLEAR_SCAN_BACK_PARAM        (MF_CLEAR_SCAN_FRONT_PARAM + 1)
#define     MF_CLEAR_PRINT_PARAM            0x0024
#define     MF_CLEAR_PROCESS_PARAM          0x0025
#define     MF_CLEAR_BARCODE_FRONT_PARAM    0x0027
#define     MF_CLEAR_BARCODE_PARAM          0x0027
#define     MF_CLEAR_BARCODE_BACK_PARAM     (MF_CLEAR_BARCODE_FRONT_PARAM + 1)

#define     MF_GET_BASE_DEFAULT             0x0030
#define     MF_GET_MICR_DEFAULT             0x0031
#define     MF_GET_SCAN_DEFAULT             0x0032
#define     MF_GET_SCAN_FRONT_DEFAULT       0x0032
#define     MF_GET_SCAN_BACK_DEFAULT        (MF_GET_SCAN_FRONT_DEFAULT + 1)
#define     MF_GET_PRINT_DEFAULT            0x0034
#define     MF_GET_PROCESS_DEFAULT          0x0035
#define     MF_GET_BARCODE_DEFAULT          0x0037
#define     MF_GET_BARCODE_FRONT_DEFAULT    0x0037
#define     MF_GET_BARCODE_BACK_DEFAULT     (MF_GET_BARCODE_FRONT_DEFAULT + 1)



/******************************************************************************/
/******************************************************************************/
/* MF Fuction Structure                                                       */
/******************************************************************************/
/******************************************************************************/
#if defined(WIN32)
#pragma pack(push, 1)   /* set structure packing to 1 */
#endif

/*========================================================*/
/* Base parameters                                        */
/*========================================================*/
/*------------------------------------*/
/* struct version(for iVersion)       */
/*------------------------------------*/
#define     MF_BASE_VERSION01               0x0101
/*------------------------------------*/
/* Event notice type(for dwNotifyType)*/
/*------------------------------------*/
#define     MF_BASE_MESSAGE_NO_MESSAGE      1
#define     MF_BASE_MESSAGE_NOTIFY_MAX      MF_BASE_MESSAGE_NO_MESSAGE
/*------------------------------------*/
/* Paper insertion timeout            */
/* (for dwTimeout)                    */
/*------------------------------------*/
#define     MF_BASE_TIMEOUT_MAX             300     /* 5 min    */
#define     MF_BASE_TIMEOUT_DEFAULT         0       /* INFINITE */
/*------------------------------------*/
/* NV memory use type                 */
/* (for bUseNVMemory)                 */
/*------------------------------------*/
#define     MF_BASE_NVMEMORY_NOT_USE        0
/*------------------------------------*/
/* Paper eject type                   */
/* (for wErrorEject and wSuccessEject)*/
/*------------------------------------*/
#define     MF_EJECT_DISCHARGE              0x0000
#define     MF_EJECT_RELEASE                0x0001
#define     MF_EJECT_FRONT                  MF_EJECT_DISCHARGE
#define     MF_EJECT_REAR                   MF_EJECT_RELEASE
#define     MF_EJECT_NONE                   0x0002
#define     MF_EXIT_ERROR_DISCHARGE         MF_EJECT_DISCHARGE
#define     MF_EXIT_ERROR_RELEASE           MF_EJECT_RELEASE
#define     MF_EXIT_SUCCESS_DISCHARGE       MF_EJECT_DISCHARGE
#define     MF_EXIT_SUCCESS_RELEASE         MF_EJECT_RELEASE
#define     MF_EXIT_ERROR_FRONT_SIDE        MF_EJECT_DISCHARGE
#define     MF_EXIT_ERROR_REAR_SIDE         MF_EJECT_RELEASE
#define     MF_EXIT_ERROR_NOEJECT           MF_EJECT_NONE
#define     MF_EXIT_SUCCESS_FRONT_SIDE      MF_EJECT_DISCHARGE
#define     MF_EXIT_SUCCESS_REAR_SIDE       MF_EJECT_RELEASE
#define     MF_EXIT_SUCCESS_NOEJECT         MF_EJECT_NONE
/*------------------------------------*/
/* Buzzer factor type(for bBuzzerHz and bBuzzerCount)  */
/*------------------------------------*/
#define     MF_BUZZER_TYPE_MAX              3
/*------------------------------------*/
/* Buzzer type(for bBuzzerHz)         */
/*------------------------------------*/
#define     MF_BUZZER_HZ_4000               0
/*------------------------------------*/
/* Buzzer count(for bBuzzerCount)     */
/*------------------------------------*/
#define     MF_BUZZER_DISABLE               0
/*------------------------------------*/
/* Base Structure (Version 0x0101)    */
/*------------------------------------*/
typedef struct {
/* Base Section */
    int             iSize;
    int             iVersion;
    int             iRet;
    EPBS_UINT32     dwNotifyType;
    EPBS_UINT32     dwTimeout;
    union {
        EPBS_PHANDLE    lphNotifyEvent;
        EPBS_HWND       hNotifyWnd;
    } uNotifyHandle;
    EPBS_HWND       hProgressWnd;
    EPBS_UINT16     wErrorEject;
    EPBS_UINT8      bBuzzerHz[MF_BUZZER_TYPE_MAX];
    EPBS_UINT8      bBuzzerCount[MF_BUZZER_TYPE_MAX];
    EPBS_UINT8      bUseNVMemory;
    char            cPortName[256];
    EPBS_UINT16     wSuccessEject;
} MF_BASE01, *LPMF_BASE01;

/*========================================================*/
/* Scan parameters                                        */
/*========================================================*/
/*------------------------------------*/
/* Structure version                  */
/*------------------------------------*/
#define     MF_SCAN_VERSION                 0x0100
/*------------------------------------*/
/* Scan resolution(for sResolution)   */
/*------------------------------------*/
#define     MF_SCAN_DPI_DEFAULT             0
#define     MF_SCAN_DPI_75                  75
#define     MF_SCAN_DPI_100                 100
#define     MF_SCAN_DPI_120                 120
#define     MF_SCAN_DPI_200                 200
#define     MF_SCAN_DPI_240                 240
#define     MF_SCAN_DPI_300                 300
#define     MF_SCAN_DPI_400                 400
#define     MF_SCAN_DPI_600                 600
/*------------------------------------*/
/* Scan structure                     */
/*------------------------------------*/
typedef struct{
/* Scan Section */
    int             iSize;
    int             iVersion;
    int             iRet;
    EPBS_UINT16     wImageID;
    short           sResolution;
    EPBS_UINT8      bAddInfoDataSize;
    EPBS_PUINT8     pAddInfoData;
    EPBS_UINT8      bStatus;
    EPBS_UINT8      bDetail;
    EPBS_UINT32     dwXSize;
    EPBS_UINT32     dwYSize;
    EPBS_UINT32     dwScanSize;
    EPBS_PUINT8     lpbScanData;
} MF_SCAN, *LPMF_SCAN;

/*========================================================*/
/* MICR parameters                                        */
/*========================================================*/
/*------------------------------------*/
/* Structure version(for iVersion)    */
/*------------------------------------*/
#define     MF_MICR_VERSION                 0x0100
/*------------------------------------*/
/* MICR type(for bMicOcrSelect)       */
/*------------------------------------*/
#define     MF_MICR_USE_MICR                0x00000001
#define     MF_MICR_USE_OCR                 0x00000002
#define     MF_MICR_READ_RETRY              0x00000004
#define     MF_MICOCR_READ_RETRY            0x00000008
/*------------------------------------*/
/* Font(for bFont)                    */
/*------------------------------------*/
#define     MF_MICR_FONT_E13B               0
#define     MF_MICR_FONT_CMC7               1
#define     MF_MICR_FONT_CMC7_NUM           MF_MICR_FONT_CMC7
#define     MF_MICR_FONT_CMC7_ALPHANUM      3

#define     MF_MICR_CHAR_MAX                81
#define     MF_MICR_CHAR_LEN                80
/*------------------------------------*/
/* Reliability structure              */
/*------------------------------------*/
typedef struct{
    EPBS_CHAR   cRecogChar;         /* Recognized character */
    EPBS_INT32  lPercentage;        /* Reliability(%)       */
} MF_OCR_RELIABILITY;
/*------------------------------------*/
/* Reliability information structure  */
/*------------------------------------*/
typedef struct{
    EPBS_INT32          lPosition;          /* Position(0 is left edge)     */
    MF_OCR_RELIABILITY  stFirstSelect;      /* First recognition candidate  */
    MF_OCR_RELIABILITY  stSecondSelect;     /* Second recognition candidate */
} MF_OCR_RELIABLE_INFO;
/*------------------------------------*/
/* MICR/OCR structure                 */
/*------------------------------------*/
typedef struct{
/* MIC_OCR Section */
    int                     iSize;
    int                     iVersion;
    int                     iRet;
    EPBS_UINT8              bFont;
    EPBS_UINT8              bMicOcrSelect;
    EPBS_BOOL               blParsing;
    EPBS_UINT8              bStatus;
    EPBS_UINT8              bDetail;
    EPBS_CHAR               szMicrStr[MF_MICR_CHAR_MAX];
    MF_OCR_RELIABLE_INFO    stOcrReliableInfo[MF_MICR_CHAR_MAX];
    EPBS_CHAR               szAccountNumber[MF_MICR_CHAR_MAX];
    EPBS_CHAR               szAmount[MF_MICR_CHAR_MAX];
    EPBS_CHAR               szBankNumber[MF_MICR_CHAR_MAX];
    EPBS_CHAR               szSerialNumber[MF_MICR_CHAR_MAX];
    EPBS_CHAR               szEPC[MF_MICR_CHAR_MAX];
    EPBS_CHAR               szTransitNumber[MF_MICR_CHAR_MAX];
    long                    lCheckType;
    long                    lCountryCode;
} MF_MICR, *LPMF_MICR;

/*========================================================*/
/* OCR_AB parameters                                      */
/*========================================================*/
/*------------------------------------*/
/* Structure version(for iVersion)    */
/*------------------------------------*/
#define     MF_OCR_AB_VERSION               0x0100
/*------------------------------------*/
/* Ocr Type                           */
/*------------------------------------*/
#define     MF_OCR_FONT_OCRA_NUM                1
#define     MF_OCR_FONT_OCRA_ALPHA              2
#define     MF_OCR_FONT_OCRA_ALPHANUM           3
#define     MF_OCR_FONT_OCRA_ALPHANUM_WOOH      7
#define     MF_OCR_FONT_OCRA_ALPHANUM_WOZERO    11
#define     MF_OCR_FONT_OCRB_NUM                17
#define     MF_OCR_FONT_OCRB_ALPHA              18
#define     MF_OCR_FONT_OCRB_ALPHANUM           19
#define     MF_OCR_FONT_OCRB_ALPHANUM_WOOH      23
#define     MF_OCR_FONT_OCRB_ALPHANUM_WOZERO    27
#define     MF_OCR_FONT_OCRA_SYMNUM             33
#define     MF_OCR_FONT_OCRB_SYMNUM             49
/*------------------------------------*/
/* Direction                          */
/*------------------------------------*/
#define     MF_OCR_LEFTRIGHT                1
#define     MF_OCR_TOPBOTTOM                2
#define     MF_OCR_RIGHTLEFT                3
#define     MF_OCR_BOTTOMTOP                4
/*------------------------------------*/
/* Area(for bEndX, bEndY)             */
/*------------------------------------*/
#define     OCR_AREA_RIGHT                  65535
#define     OCR_AREA_BOTTOM                 65535
#define     OCR_AREA_TOP                    65535
#define     OCR_AREA_LEFT                   65535
/*------------------------------------*/
/* SpeceHandling(for bSpeceHandling)  */
/*------------------------------------*/
#define     OCR_SPACE_ENABLE                1
#define     OCR_SPACE_DISABLE               0

#define     MF_OCR_AB_CHAR_MAX              128
/*------------------------------------*/
/* OCR AB structure                   */
/*------------------------------------*/
typedef struct{
    int                     iSize;
    int                     iVersion;
    int                     iRet;
    EPBS_UINT8              bOcrType;
    EPBS_UINT8              bDirection;
    EPBS_UINT16             wStartX;
    EPBS_UINT16             wStartY;
    EPBS_UINT16             wEndX;
    EPBS_UINT16             wEndY;
    EPBS_UINT8              bSpaceHandling;
    EPBS_CHAR               szOcrStr[MF_OCR_AB_CHAR_MAX];
    MF_OCR_RELIABLE_INFO    stOcrReliableInfo[MF_OCR_AB_CHAR_MAX];
} MF_OCR_AB, *LPMF_OCR_AB;

/*========================================================*/
/* Process parameters                                     */
/*========================================================*/
/*------------------------------------*/
/* Structure version(for iVersion)    */
/*------------------------------------*/
#define     MF_PROCESS_VERSION              0x0100
/*------------------------------------*/
/* Activation mode(For bActivationMode) */
/*------------------------------------*/
#define     MF_ACTIVATE_MODE_CONFIRMATION   0
#define     MF_ACTIVATE_MODE_HIGH_SPEED     1
#define     MF_ACTIVATE_MODE_AUTO           MF_ACTIVATE_MODE_HIGH_SPEED
/*------------------------------------*/
/* Paper type(For bPaperType)         */
/*------------------------------------*/
#define     MF_PAPER_TYPE_CHECK             1
/*------------------------------------*/
/* Stamp status(For bSuccessStamp, bPaperMisInsertionStamp, bNoiseStamp */
/*              , bDoubleFeedStamp, bBaddataStamp, bNodataStamp)        */
/*------------------------------------*/
#define     MF_STAMP_DISABLE                0
#define     MF_STAMP_ENABLE                 1
/*------------------------------------*/
/* Error detect(For bPaperMisInsertionErrorSelect, bNoiseErrorSelect               */
/*              , bDoubleFeedErrorSelect, bBaddataErrorSelect, bNodataErrorSelect) */
/*------------------------------------*/
#define     MF_ERROR_SELECT_NODETECT        0
#define     MF_ERROR_SELECT_DETECT          1
/*------------------------------------*/
/* Eject select(For bPaperMisInsertionErrorEject, bNoiseErrorEject              */
/*              , bDoubleFeedErrorEject, bBaddataErrorEject, bNodataErrorEject) */
/*------------------------------------*/
#define     MF_EJECT_MAIN_POCKET            0x22
#define     MF_EJECT_SUB_POCKET             0x24
#define     MF_EJECT_FRONT_SIDE             0x22
#define     MF_EJECT_REAR_SIDE              0x24
#define     MF_EJECT_NOEJECT                0x28
/*------------------------------------*/
/* Cancel status(For bPaperMisInsertionCancel, bNoiseCancel, bDoubleFeedCancel */
/*              , bBaddataCancel, bNodataCancel)                               */
/*------------------------------------*/
#define     MF_CANCEL_DISABLE               0
#define     MF_CANCEL_ENABLE                1
/*------------------------------------*/
/* Nearfull parmit(For bNearFullSelect) */
/*------------------------------------*/
#define     MF_NEARFULL_PERMIT              0x03
/*------------------------------------*/
/* Result partial(For bResultPartialData) */
/*------------------------------------*/
#define     MF_RESULT_NONE                  0
#define     MF_RESULT_PARTIAL               1
/*------------------------------------*/
/* Process structure                  */
/*------------------------------------*/
typedef struct{
/* Process Section */
    int             iSize;
    int             iVersion;
    EPBS_UINT8      bActivationMode;
    EPBS_UINT8      bPaperType;
    EPBS_UINT32     dwStartWaitTime;
    EPBS_UINT8      bSuccessStamp;
    EPBS_UINT8      bPaperMisInsertionErrorSelect;
    EPBS_UINT8      bPaperMisInsertionErrorEject;
    EPBS_UINT8      bPaperMisInsertionStamp;
    EPBS_UINT8      bPaperMisInsertionCancel;
    EPBS_UINT8      bNoiseErrorSelect;
    EPBS_UINT8      bNoiseErrorEject;
    EPBS_UINT8      bNoiseStamp;
    EPBS_UINT8      bNoiseCancel;
    EPBS_UINT8      bDoubleFeedErrorSelect;
    EPBS_UINT8      bDoubleFeedErrorEject;
    EPBS_UINT8      bDoubleFeedStamp;
    EPBS_UINT8      bDoubleFeedCancel;
    EPBS_UINT8      bBaddataErrorSelect;
    EPBS_UINT8      bBaddataCount;
    EPBS_UINT8      bBaddataErrorEject;
    EPBS_UINT8      bBaddataStamp;
    EPBS_UINT8      bBaddataCancel;
    EPBS_UINT8      bNodataErrorSelect;
    EPBS_UINT8      bNodataErrorEject;
    EPBS_UINT8      bNodataStamp;
    EPBS_UINT8      bNodataCancel;
    EPBS_UINT8      bNearFullSelect;
    EPBS_UINT8      bResultPartialData;
} MF_PROCESS, *LPMF_PROCESS;

/*========================================================*/
/* Print parameters                                       */
/*========================================================*/
/*------------------------------------*/
/* Structure version(for iVersion)    */
/*------------------------------------*/
#define     MF_PRINT_VERSION01              0x0101
#define     MF_PRINT_VERSION                0x0100
/*------------------------------------*/
/* Line number(for lpString,dwAttribute,wFont and wfontSize) */
/*------------------------------------*/
#define     MF_PRINT_LINE_1                 0
#define     MF_PRINT_LINE_2                 1
#define     MF_PRINT_LINE_3                 2
#define     MF_PRINT_LINE_MAX               MF_PRINT_LINE_3
/*------------------------------------*/
/* Charactor attribute(for dwAttribute) */
/*------------------------------------*/
#define     MF_PRINT_NO_ATTRIBUTE           0x00000000
#define     MF_PRINT_BOLD                   0x00000001
#define     MF_PRINT_UNDERLINE_1            0x00000010
#define     MF_PRINT_UNDERLINE_2            0x00000020
#define     MF_PRINT_BLACK                  0x00000100
#define     MF_PRINT_1ST_COLOR              0x00000100
#define     MF_PRINT_COLOR                  0x00000200
#define     MF_PRINT_2ND_COLOR              0x00000200
#define     MF_PRINT_MIXED                  0x00000300
#define     MF_PRINT_REVERSEVIDEO           0x00001000
/*------------------------------------*/
/* Font type(for wFont)               */
/*------------------------------------*/
#define     MF_PRINT_FONT_A                 1
#define     MF_PRINT_FONT_B                 2
#define     MF_PRINT_SYSTEMFONT             3
#define     MF_PRINT_ROMAN_FONT             MF_PRINT_FONT_A
#define     MF_PRINT_SANSSERIF_FONT         MF_PRINT_FONT_B
#define     MF_PRINT_COURIER_FONT           4
#define     MF_PRINT_PRESTIGE_FONT          5
#define     MF_PRINT_OCRB_FONT              6
#define     MF_PRINT_OCRA_FONT              7
#define     MF_PRINT_ORATOR_FONT            8
#define     MF_PRINT_ORATORS_FONT           9
#define     MF_PRINT_SCRIPTC_FONT           10
#define     MF_PRINT_ROMANT_FONT            11
#define     MF_PRINT_SANSSELIFH_FONT        12
#define     MF_PRINT_FARSI_FONT             13
/*------------------------------------*/
/* Font size(for wFontSize)           */
/*------------------------------------*/
#define     MF_PRINT_FONT_W1_H1             0x0011
#define     MF_PRINT_FONT_W1_H2             0x0012
#define     MF_PRINT_FONT_W2_H1             0x0021
#define     MF_PRINT_FONT_W2_H2             0x0022
/*------------------------------------*/
/* Printing speed(for bSpeed)         */
/*------------------------------------*/
#define     MF_PRINT_SPEED_HIGH             1
/*------------------------------------*/
/* PrintDirection(for bDirection)     */
/*------------------------------------*/
#define     MF_PRINT_DIRECTION_DOUBLE       0
/*------------------------------------*/
/* Endorse type                       */
/*------------------------------------*/
#define     MF_PRINT_TYPE_ENDORSE_ONLY                  0
#define     MF_PRINT_TYPE_ENDORSE_NORMAL                1
#define     MF_PRINT_TYPE_ELECTRIC_ENDORSE_ONLY         2
#define     MF_PRINT_TYPE_ENDORSE_ONLY_BEFORE_SCAN      5
/*------------------------------------*/
/* print structure(version 0x0101)    */
/*------------------------------------*/
typedef struct{
/* Print Section */
    int             iSize;
    int             iVersion;
    int             iRet;
    EPBS_BOOL       blDummy;
    EPBS_PCHAR      lpString[3];
    EPBS_UINT32     dwAttribute[3];
    EPBS_UINT16     wFont[3];
    EPBS_UINT16     wFontSize[3];
    EPBS_UINT8      bSpeed;
    EPBS_BOOL       bDirection;
    EPBS_UINT32     dwEndorseType;
} MF_PRINT01, *LPMF_PRINT01;

/*========================================================*/
/* Barcode parameters                                     */
/*========================================================*/
/*------------------------------------*/
/* Structure version(for iVersion)    */
/*------------------------------------*/
#define     MF_BARCODE_VERSION              0x0100
/*------------------------------------*/
/* Barcode symbol                     */
/*------------------------------------*/
#define     MF_BARCODE_SYMBOL_CODABAR       (0x00000001)
#define     MF_BARCODE_SYMBOL_CODE128       (0x00000002)
#define     MF_BARCODE_SYMBOL_CODE39        (0x00000004)
#define     MF_BARCODE_SYMBOL_ITF           (0x00000008)
#define     MF_BARCODE_SYMBOL_EAN_JAN       (0x00000010)
#define     MF_BARCODE_SYMBOL_UPC_A         (0x00000020)
#define     MF_BARCODE_SYMBOL_UPC_E         (0x00000040)
/*------------------------------------*/
/* Barcode direction                  */
/*------------------------------------*/
#define     MF_BARCODE_DIRECTION_ALL        0
#define     MF_BARCODE_DIRECTION_LEFTRIGHT  1
#define     MF_BARCODE_DIRECTION_TOPBOTTOM  2
#define     MF_BARCODE_DIRECTION_RIGHTLEFT  3
#define     MF_BARCODE_DIRECTION_BOTTOMTOP  4
/*------------------------------------*/
/* Barcode area origin                */
/*------------------------------------*/
#define     MF_BARCODE_ORIGIN_TOP_LEFT      0
#define     MF_BARCODE_ORIGIN_BOTTOM_LEFT   1
#define     MF_BARCODE_ORIGIN_TOP_RIGHT     2
#define     MF_BARCODE_ORIGIN_BOTTOM_RIGHT  3
/*------------------------------------*/
/* Barcode color                      */
/*------------------------------------*/
#define     MF_BARCODE_TARGET_COLOR_GRAY    0
#define     MF_BARCODE_TARGET_COLOR_RED     1
#define     MF_BARCODE_TARGET_COLOR_GREEN   2
#define     MF_BARCODE_TARGET_COLOR_BLUE    3
#define     MF_BARCODE_TARGET_COLOR_UV      4
/*------------------------------------*/
/* Area(for wEndX, wEndY)             */
/*------------------------------------*/
#define     MF_BARCODE_AREA_RIGHT           65535
#define     MF_BARCODE_AREA_BOTTOM          65535
/*------------------------------------*/
/* Barcode data                       */
/*------------------------------------*/
typedef struct {
    EPBS_UINT32     dwSymbol;
    EPBS_UINT16     wStartX;
    EPBS_UINT16     wStartY;
    EPBS_UINT16     wEndX;
    EPBS_UINT16     wEndY;
    EPBS_UINT32     dwDataSize;     /* data length          */
    EPBS_PVOID      pData;          /* barcode data(binary) */
} BARCODE_DATA, *LPBARCODE_DATA;
/*------------------------------------*/
/* Barcode decode information         */
/*------------------------------------*/
typedef struct {
    int     iRet;
    EPBS_UINT8      bStatus;
    EPBS_UINT8      bDetail;
    EPBS_UINT32     dwSymbolMask;
    EPBS_UINT8      bDirection;
    EPBS_UINT8      bOrigin;
    EPBS_UINT16     wStartX;
    EPBS_UINT16     wStartY;
    EPBS_UINT16     wEndX;
    EPBS_UINT16     wEndY;
} BARCODE_INFO, *LPBARCODE_INFO;
/*------------------------------------*/
/* Barcode structure                  */
/*------------------------------------*/
typedef struct{
/* Barcode Section */
    int             iSize;
    int             iVersion;
    int             iRet;

    EPBS_UINT8      bErrorSelect;
    EPBS_UINT8      bErrorEject;
    EPBS_UINT8      bStamp;
    EPBS_UINT8      bCancel;

    EPBS_UINT32     dwTargetColor;
    short           sResolution;
    EPBS_UINT32     dwInfoMode;
    BARCODE_INFO    stInfo[5];
    EPBS_UINT8      bDataCount;     /* array size for lpData */
    EPBS_PVOID      lpData;         /* array of BARCODE_DATA */
} MF_BARCODE, *LPMF_BARCODE;

/*========================================================*/
/* VERSION_INFO parameters                                */
/*========================================================*/
#define     VERSION_CHAR_MAX                64

typedef struct{
    EPBS_CHAR    lpszDescription[VERSION_CHAR_MAX];
    EPBS_CHAR    lpszVersion[VERSION_CHAR_MAX];
} VERSION_INFO, *LPVERSION_INFO;

/*========================================================*/
/* DECORATE parameters                                    */
/*========================================================*/
typedef struct {
    EPBS_UINT32     dwAttribute;
    EPBS_UINT16     wFont;
    EPBS_PCHAR      szFontName;
    EPBS_UINT16     wFontSize;
} MF_DECORATE, *LPMF_DECORATE;

/*========================================================*/
/* MSRW parameters                                        */
/*========================================================*/
#define     MF_MSRW_VERSION                 0x0100

#define     EPS_BI_MSRW_FORMAT_IBM3604      1
#define     EPS_BI_MSRW_FORMAT_DINISO       2
#define     EPS_BI_MSRW_FORMAT_ANSI         3
#define     EPS_BI_MSRW_FORMAT_IBM4746      4
#define     EPS_BI_MSRW_FORMAT_ISO7811      5
#define     EPS_BI_MSRW_FORMAT_HT2751CIZ    6
#define     EPS_BI_MSRW_FORMAT_ISO8484      7

#define     EPS_BI_MSRW_EOM_NONE            0
#define     EPS_BI_MSRW_EOM_3C              1
#define     EPS_BI_MSRW_EOM_3F              2

typedef struct
{
    int             iSize;
    int             iVersion;
    EPBS_UINT32     dwRecordFormat;
    EPBS_UINT32     dwIBMDataType;
    EPBS_UINT32     dwReadRetry;
    EPBS_UINT32     dwWriteAndClearRetry;
    EPBS_UINT32     dwBlockCount;
    EPBS_UINT32     dwVerticalAdjust;
} MF_MSRW, *LPMF_MSRW;

/*========================================================*/
/* GET Stored Image Info parameters                       */
/*========================================================*/
#define     MF_STORED_IMAGE_INFO_VERION     0x0100
typedef struct {
	int iSize;                   /* IN */
	int iVersion;                /* IN */
	EPBS_UINT8  bColorDepth;     /* OUT */
	EPBS_UINT8  bColor;          /* OUT */
	EPBS_UINT8  bFormat;         /* OUT */
	EPBS_UINT16 wImageWidth;     /* OUT */
	EPBS_UINT16 wImageHeight;    /* OUT */
	short sResolution;           /* OUT */
} MF_STORED_IMAGE_INFO, *LPMF_STORED_IMAGE_INFO;

/*========================================================*/
/* PDF DATA parameters                                    */
/*========================================================*/
#define     MF_PDFDATA_VERSION              0x0100

typedef struct
{
    int             iSize;
    int             iVersion;
    EPBS_UINT32     dwFileIndex;
    EPBS_PCHAR      pFileID;
    EPBS_PCHAR      pImageTagData;
    EPBS_RECT*      pRect;
} MF_PDFDATA, *LPMF_PDFDATA;

/*========================================================*/
/* PDF PAGE parameters                                    */
/*========================================================*/
#define     MF_PDFPAGE_VERSION              0x0100

#define     PDFPAGE_ROTATE_0                0
#define     PDFPAGE_ROTATE_90               90
#define     PDFPAGE_ROTATE_180              180
#define     PDFPAGE_ROTATE_270              270

typedef struct
{
    int             iSize;
    int             iVersion;
    int             iRotate;
    int             iPageWidth;
    int             iPageHeight;
    EPBS_RECT*      pRect;
    LPMF_PDFDATA    pData;
    int             iDataLength;
}MF_PDFPAGE, *LPMF_PDFPAGE;

/*========================================================*/
/* PDF FILE parameters                                    */
/*========================================================*/
#define     MF_PDFFILE_VERSION              0x0100

#define     BLANKPAGE_LEVEL_NONE            0
#define     BLANKPAGE_LEVEL_1               1
#define     BLANKPAGE_LEVEL_2               2
#define     BLANKPAGE_LEVEL_3               3

#define     PDFFILE_COMPRESSION_STANDARD    0
#define     PDFFILE_COMRESSION_HIGH         1

typedef struct
{
    int             iSize;
    int             iVersion;
    EPBS_PCHAR      pFilePath;
    EPBS_PCHAR      pFileName;
    EPBS_PCHAR      pAuthor;
    EPBS_PCHAR      pSubjectName;
    EPBS_PCHAR      pApplicationName;
    EPBS_UINT32     dwCompression;
    EPBS_UINT32     dwBlankPage;
    LPMF_PDFPAGE    pPage;
    int             iPageLength;
} MF_PDFFILE, *LPMF_PDFFILE;

#if defined(WIN32)
#pragma pack(pop)    /* pop structure packing back to previous state */
#endif

#endif  /* !defined(_PLQSTATUSAPIDEF_H) */
